h-recipe parsing tests

# h-recipe parsing tests ‐ change logs

The files in this directory where designed to test the parsing of h-recipe.

## Change log:

- Update text output to be textContent non-trimmed for all test ‐ 29 May 2015 by Glenn Jones
- Broke old HTML format into small files to aid simpler testing ‐ 21 May 2015 by Glenn Jones
- Updated JSON examples so it always has the rel={} object as well as the items=[] array ‐ 21 November 2013 by Glenn Jones
- Created ‐ 14 January 2013 by Glenn Jones

## Contributors:

- Glenn Jones